vfbLib.parsers.options.OpenTypeExportOptionsParser
==================================================

.. currentmodule:: vfbLib.parsers.options

.. autoclass:: OpenTypeExportOptionsParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~OpenTypeExportOptionsParser.__init__
      ~OpenTypeExportOptionsParser.parse
      ~OpenTypeExportOptionsParser.parse_hex
      ~OpenTypeExportOptionsParser.read_double
      ~OpenTypeExportOptionsParser.read_doubles
      ~OpenTypeExportOptionsParser.read_float
      ~OpenTypeExportOptionsParser.read_floats
      ~OpenTypeExportOptionsParser.read_int16
      ~OpenTypeExportOptionsParser.read_int32
      ~OpenTypeExportOptionsParser.read_int8
      ~OpenTypeExportOptionsParser.read_str
      ~OpenTypeExportOptionsParser.read_str_all
      ~OpenTypeExportOptionsParser.read_uint16
      ~OpenTypeExportOptionsParser.read_uint32
      ~OpenTypeExportOptionsParser.read_uint8
      ~OpenTypeExportOptionsParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~OpenTypeExportOptionsParser.encoding
      ~OpenTypeExportOptionsParser.master_count
      ~OpenTypeExportOptionsParser.stream
      ~OpenTypeExportOptionsParser.ttStemsH_count
      ~OpenTypeExportOptionsParser.ttStemsV_count
   
   